@@ -32,15 +32,15 @@ EVENT_CONNECTION_RESTORED = "connection_restored"
 EVENT_DISARMED_BY_MASTER_PIN = "disarmed_by_master_pin"
 EVENT_DISARMED_BY_REMOTE = "disarmed_by_remote"
 EVENT_DOORBELL_DETECTED = "doorbell_detected"
-EVENT_ENTRY_DETECTED = "entry_detected"
 EVENT_ENTITY_TEST = "entity_test"
+EVENT_ENTRY_DELAY = "entry_delay"
 EVENT_HOME_EXIT_DELAY = "home_exit_delay"
 EVENT_LOCK_ERROR = "lock_error"
 EVENT_LOCK_LOCKED = "lock_locked"
 EVENT_LOCK_UNLOCKED = "lock_unlocked"
-EVENT_MOTION_DETECTED = "motion_detected"
 EVENT_POWER_OUTAGE = "power_outage"
 EVENT_POWER_RESTORED = "power_restored"
+EVENT_SECRET_ALERT_TRIGGERED = "secret_alert_triggered"
 EVENT_SENSOR_NOT_RESPONDING = "sensor_not_responding"
 EVENT_SENSOR_PAIRED_AND_NAMED = "sensor_paired_and_named"
 EVENT_SENSOR_RESTORED = "sensor_restored"
@@ -61,8 +61,8 @@ EVENT_MAPPING = {
     1400: EVENT_DISARMED_BY_MASTER_PIN,
     1406: EVENT_ALARM_CANCELED,
     1407: EVENT_DISARMED_BY_REMOTE,
-    1409: EVENT_MOTION_DETECTED,
-    1429: EVENT_ENTRY_DETECTED,
+    1409: EVENT_SECRET_ALERT_TRIGGERED,
+    1429: EVENT_ENTRY_DELAY,
     1458: EVENT_DOORBELL_DETECTED,
     1531: EVENT_SENSOR_PAIRED_AND_NAMED,
     1601: EVENT_USER_INITIATED_TEST,
